pub struct TestMdata {
pub version: u32,
pub iterations: Option<NonZero<usize>>,
pub importance: Importance,
pub weight: u8,
}Expand description
Information about a given perf test.
Fields
version: u32A version number for when the test was generated. If this is greater than the version this test handler expects, one of the following will happen in an unspecified manner:
- The test is skipped silently.
- The handler exits with an error message indicating the version mismatch or inability to parse the metadata.
INVARIANT: If version <= MDATA_VER, this tool must be able to
correctly parse the output of this test.
iterations: Option<NonZero<usize>>How many iterations to pass this test if this is preset, or how many iterations a test ended up running afterwards if determined at runtime.
importance: ImportanceThe importance of this particular test. See the docs on Importance for
details.
weight: u8The weight of this particular test within its importance category. Used when comparing across runs.